@@ -32,10 +32,13 @@ import os
 
 # This is to figure out the affiliated package version, rather than
 # using Astropy's
-from . import version
+try:
+    from .version import version
+except ImportError:
+    version = 'dev'
 
 try:
     packagename = os.path.basename(os.path.dirname(__file__))
-    TESTED_VERSIONS[packagename] = version.version
+    TESTED_VERSIONS[packagename] = version
 except NameError:   # Needed to support Astropy <= 1.0.0
     pass
